#!/bin/sh
# exb2exb.sh -- transform an EXB file
# Andreas Nolda 2020-07-02

set -e

progname=$(basename $0)
progpath=$(dirname $(realpath $0))

# uncomment and set this variable if TreeTagger is installed in a non-standard
# directory
#TREETAGGER_HOME=
if [ -z "$TREETAGGER_HOME" ]; then
  if [ -d "$HOME/tree-tagger" ]; then
    TREETAGGER_HOME=$HOME/tree-tagger
  elif [ -d "/opt/tree-tagger" ]; then
    TREETAGGER_HOME=/opt/tree-tagger
  else
    echo "TreeTagger not found. Please set \"TREETAGGER_HOME\" in \"$0\"."
    exit 1
  fi
fi
export TREETAGGER_HOME

# uncomment and set this variable if EXMARaLDA is installed in a non-standard
# directory
#EXMARALDADIR=
if [ -z "$EXMARALDADIR" ]; then
  if [ -d "$HOME/exmaralda" ]; then
    EXMARALDADIR="$HOME/exmaralda"
  elif [ -d /opt/exmaralda ]; then
    EXMARALDADIR=/opt/exmaralda
  else
    echo "EXMARaLDA Partitur-Editor not found. Please set \"EXMARALDADIR\" in \"$0\"."
    exit 1
  fi
fi

EXMARALDADULKODIR=$progpath
TT4JDULKODIR=$progpath
SAXONDIR=$progpath

JAVA_OPTIONS="-Xmx512M"

CP_JAVA=$SAXONDIR/saxon9.jar
CP_JAVA_TT=$CP_JAVA:$TT4JDULKODIR/tt4j-dulko.jar:$EXMARALDADIR/lib/EXMARaLDA.jar

saxon="java $JAVA_OPTIONS -classpath $CP_JAVA net.sf.saxon.Transform -expand:off"
saxon_tt="java $JAVA_OPTIONS -classpath $CP_JAVA_TT net.sf.saxon.Transform -expand:off"

usage="\
Usage: $progname [-a] [--annis]
                  [-d] [--diff]
                  [-D] [--displayname]
                  [-f] [--fehler]
                  [-g] [--graph]
                  [-l] [--layout]
                  [-m] [--metadata]
                  [-n <ZH number>] [--number <ZH number>]
                  [-o] [--orig]
                  [-p] [--pos-lemma]
                  [-s] [--s-spans]
                  [-S] [--s-span-numbers]
                  [-t] [--trans]
                  [-T] [--timeline-items]
                  [-w] [--word]
                  [-z] [--zh]
                  <EXB file>
       $progname [-h] [--help]"
version=2.6

file=
n=
stylesheet=
tt=

if [ $# -eq 0 ] ; then
  echo "$usage" 1>&2
  exit 1
else
  while [ $# -gt 0 ]; do
    case "$1" in
      -a | --annis)
        stylesheet=exb2exb-annis.xsl;;
      -d | --diff)
        stylesheet=exb2exb-diff.xsl;;
      -D | --displayname)
        stylesheet=exb2exb-displayname.xsl;;
      -f | --fehler)
        stylesheet=exb2exb-fehler.xsl;;
      -g | --graph)
        stylesheet=exb2exb-graph.xsl;;
      -l | --layout)
        stylesheet=exb2exb-layout.xsl;;
      -m | --metadata)
        stylesheet=exb2exb-metadata.xsl;;
      -n | --zh-number)
        shift;
        n=$1;;
      -o | --orig)
        stylesheet=exb2exb-orig.xsl;;
      -p | --pos-lemma)
        stylesheet=exb2exb-tag.xsl;
        tt=yes;;
      -s | --s-spans)
        stylesheet=exb2exb-s.xsl;;
      -S | --s-span-numbers)
        stylesheet=exb2exb-spans.xsl;;
      -t | --trans)
        stylesheet=exb2exb-trans.xsl;;
      -T | --timeline-items)
        stylesheet=exb2exb-timeline.xsl;;
      -w | --word)
        stylesheet=exb2exb-word.xsl;;
      -z | --zh)
        stylesheet=exb2exb-zh.xsl;;
      -h | --help)
        echo "\
$progname, version $version -- transform an EXB file.";
        echo "$usage";
        exit 0;;
      -)
        file="$1";;
      -*)
        echo "$usage" 1>&2;
        exit 1;;
      *)
        file="$1";;
    esac
    shift
  done
fi
if [ -z "$stylesheet" ]; then
  echo "$usage" 1>&2
  exit 1
fi
if [ -z "$file" ]; then
  echo "$usage" 1>&2
  exit 1
fi

run_saxon() {
  if [ "$tt" = "yes" ]; then
    $saxon_tt "$1" $EXMARALDADULKODIR/share/$stylesheet $2 \!{http://saxon.sf.net/}indent-spaces=2
  else
    $saxon "$1" $EXMARALDADULKODIR/share/$stylesheet $2 \!{http://saxon.sf.net/}indent-spaces=2
  fi
}

if [ -n "$n" ]; then
  run_saxon "$file" zh-number=$n
else
  run_saxon "$file"
fi

exit 0
