#!/bin/sh
# exb2html.sh -- convert an EXB file to HTML
# Andreas Nolda 2019-04-16

set -e

progname=$(basename $0)
progpath=$(dirname $(realpath $0))

EXMARALDADULKODIR=$progpath
SAXONDIR=$progpath

JAVA_OPTIONS="-Xmx512M"

CP_JAVA=$SAXONDIR/saxon9.jar

saxon="java $JAVA_OPTIONS -classpath $CP_JAVA net.sf.saxon.Transform -expand:off"

usage="\
Usage: $progname <EXB file>
       $progname [-h] [--help]"
version=2.0

file=

if [ $# -eq 0 ] ; then
  echo "$usage" 1>&2
  exit 1
else
  while [ $# -gt 0 ]; do
    case "$1" in
      -h | --help)
        echo "\
$progname, version $version -- convert an EXB file to HTML.";
        echo "$usage";
        exit 0;;
      -)
        file="$1";;
      -*)
        echo "$usage" 1>&2;
        exit 1;;
      *)
        file="$1";;
    esac
    shift
  done
fi
if [ -z "$file" ]; then
  echo "$usage" 1>&2
  exit 1
fi

run_saxon() {
  $saxon "$1" $EXMARALDADULKODIR/share/exb2html.xsl $2 \!{http://saxon.sf.net/}indent-spaces=2
}

run_saxon "$file"

exit 0
