#!/bin/sh
# exmaralda-dulko.command -- start Dulko version of EXMARaLDA on MacOS
# Andreas Nolda 2019-10-21

cd $(dirname $0)

# uncomment and set this variable if TreeTagger is installed in a non-standard
# directory
#TREETAGGER_HOME=
if [ -z "$TREETAGGER_HOME" ]; then
  if [ -d "/Applications/tree-tagger" ]; then
    TREETAGGER_HOME=/Applications/tree-tagger
  elif [ -d "$HOME/Applications/tree-tagger" ]; then
    TREETAGGER_HOME=$HOME/Applications/tree-tagger
  elif [ -d "$HOME/Desktop/tree-tagger" ]; then
    TREETAGGER_HOME=$HOME/Desktop/tree-tagger
  elif [ -d "$HOME/Downloads/tree-tagger" ]; then
    TREETAGGER_HOME=$HOME/Downloads/tree-tagger
  else
    echo "TreeTagger not found. Please set \"TREETAGGER_HOME\" in \"$0\"."
    exit 1
  fi
fi
export TREETAGGER_HOME

# EXMARaLDA Partitur-Editor for Oracle Java (PartiturEditor_OJ.dmg)
# uncomment and set this variable if EXMARaLDA Partitur-Editor for Oracle Java
# is installed in a non-standard directory
#EXMARALDADIR=
if [ -z "$EXMARALDADIR" ]; then
  if [ -d "/Applications/PartiturEditor_OJ.app" ]; then
    EXMARALDADIR=/Applications/PartiturEditor_OJ.app/Contents/Java
  elif [ -d "$HOME/Applications/PartiturEditor_OJ.app" ]; then
    EXMARALDADIR=$HOME/Applications/PartiturEditor_OJ.app/Contents/Java
  elif [ -d "$HOME/Desktop/PartiturEditor_OJ.app" ]; then
    EXMARALDADIR=$HOME/Desktop/PartiturEditor_OJ.app/Contents/Java
  elif [ -d "/Volumes/PartiturEditor_OJ" ]; then
    EXMARALDADIR=/Volumes/PartiturEditor_OJ/PartiturEditor_OJ.app/Contents/Java
  else
    echo "EXMARaLDA Partitur-Editor not found. Please set \"EXMARALDADIR\" in \"$0\"."
    exit 1
  fi
fi

EXMARALDADULKODIR=.
TT4JDULKODIR=.
SAXONDIR=.

JAVA_HOME= # set this if Oracle Java is installed in a non-standard directory
if [ -z "$JAVA_HOME" ]; then
  if [ -d "/Library/Internet Plug-Ins/JavaAppletPlugin.plugin" ]; then
    JAVA_HOME="/Library/Internet Plug-Ins/JavaAppletPlugin.plugin/Contents/Home"
  else
    echo "Java not found. Please set \"JAVA_HOME\" in \"$0\"."
    exit 1
  fi
fi
export JAVA_HOME

MEM=256M
FONT=Sans-18
JAVA_OPTIONS="-Xmx$MEM -Dawt.useSystemAAFontSettings=on -Dswing.plaf.metal.controlFont=$FONT"

CP_JAVA=$EXMARALDADULKODIR/share:$EXMARALDADULKODIR/exmaralda-dulko.jar:$TT4JDULKODIR/tt4j-dulko.jar:$SAXONDIR/saxon9.jar:$SAXONDIR/saxon9-dom.jar:$EXMARALDADIR/EXMARaLDA.jar:$EXMARALDADIR/xalan.jar:$EXMARALDADIR/jctable.jar:$EXMARALDADIR/jdom.jar:$EXMARALDADIR/jmf.jar:$EXMARALDADIR/elan.jar:$EXMARALDADIR/BATIK.jar:$EXMARALDADIR/QTJava.zip:$EXMARALDADIR/AppleJavaExtensions.jar:$EXMARALDADIR/quaqua.jar:$EXMARALDADIR/ipsk.jar

java $JAVA_OPTIONS -classpath $CP_JAVA org.exmaralda.partitureditor.partiture.PartiturEditor $1

exit 0
