<?xml version="1.0" encoding="utf-8"?>
<!-- exb2exs.xsl -->
<!-- Version 2.2 -->
<!-- Andreas Nolda 2018-10-14 -->

<xsl:stylesheet version="2.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:include href="exb2exb.xsl"/>

<xsl:template match="/basic-transcription">
  <segmented-transcription>
    <xsl:apply-templates/>
  </segmented-transcription>
</xsl:template>

<xsl:template match="ud-meta-information">
  <ud-meta-information>
    <ud-information attribute-name="# EXB-SOURCE">
      <xsl:value-of select="substring-after(base-uri(),'file:')"/>
    </ud-information>
    <ud-information attribute-name="# GEN:w">
      <xsl:value-of select="count(/basic-transcription/basic-body/tier[@type='t']/event[not(matches(.,'^\W+$'))])"/>
    </ud-information>
    <ud-information attribute-name="# GEN:ip">
      <xsl:value-of select="count(/basic-transcription/basic-body/tier[@type='t']/event[matches(.,'^\W+$')])"/>
    </ud-information>
    <ud-information attribute-name="# e">
      <xsl:value-of select="count(/basic-transcription/basic-body/tier[@type='t']/event)"/>
    </ud-information>
    <ud-information attribute-name="# sc">
      <xsl:value-of select="count(/basic-transcription/basic-body/tier[@type='t']/event[not(@start=preceding-sibling::event/@end)]) * 2"/>
    </ud-information>
    <xsl:apply-templates/>
  </ud-meta-information>
</xsl:template>

<xsl:template match="basic-body">
  <segmented-body>
    <xsl:apply-templates select="common-timeline"/>
    <xsl:apply-templates select="tier[@type='t']"/>
  </segmented-body>
  <conversion-info>
    <basic-transcription-conversion-info>
      <xsl:apply-templates mode="conversion"/>
    </basic-transcription-conversion-info>
  </conversion-info>
</xsl:template>

<xsl:template match="common-timeline"
              mode="conversion">
  <conversion-timeline>
    <xsl:apply-templates mode="conversion"/>
  </conversion-timeline>
</xsl:template>

<xsl:template match="tli"
              mode="conversion">
  <conversion-tli>
    <xsl:copy-of select="@id"/>
  </conversion-tli>
</xsl:template>

<xsl:template name="event-content">
  <xsl:attribute name="s">
    <xsl:value-of select="@start"/>
  </xsl:attribute>
  <xsl:attribute name="e">
    <xsl:value-of select="@end"/>
  </xsl:attribute>
  <xsl:value-of select="."/>
</xsl:template>

<xsl:template name="segmentation-content">
  <xsl:param name="segment-type"/>
  <xsl:for-each select="event[not(@start=preceding-sibling::event/@end)]">
    <xsl:variable name="subtier">
      <xsl:copy-of select="."/>
      <xsl:copy-of select="following-sibling::event[not(preceding-sibling::event[preceding-sibling::event=current()]
                                                                                [not(@end=following-sibling::event/@start)])]"/>
    </xsl:variable>
    <ts n="sc">
      <xsl:attribute name="s">
        <xsl:value-of select="$subtier/event[1]/@start"/>
      </xsl:attribute>
      <xsl:attribute name="e">
        <xsl:value-of select="$subtier/event[last()]/@end"/>
      </xsl:attribute>
      <xsl:for-each select="$subtier/event">
        <xsl:choose>
          <xsl:when test="$segment-type='event'">
            <ts n="e">
              <xsl:call-template name="event-content"/>
              <xsl:text>&#x20;</xsl:text>
            </ts>
          </xsl:when>
          <xsl:when test="matches(.,'^\W+$')">
            <ts n="GEN:ip">
              <xsl:call-template name="event-content"/>
            </ts>
            <nts n="GEN:ip">
              <xsl:text>&#x20;</xsl:text>
            </nts>
          </xsl:when>
          <xsl:otherwise>
            <ts n="GEN:w">
              <xsl:call-template name="event-content"/>
            </ts>
            <nts n="GEN:ip">
              <xsl:text>&#x20;</xsl:text>
            </nts>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:for-each>
    </ts>
  </xsl:for-each>
</xsl:template>

<xsl:template match="tier[@type='t']">
  <segmented-tier>
    <xsl:copy-of select="@*"/>
    <segmentation name="SpeakerContribution_Word">
      <xsl:attribute name="tierref">
        <xsl:value-of select="@id"/>
      </xsl:attribute>
      <xsl:call-template name="segmentation-content">
        <xsl:with-param name="segment-type">word</xsl:with-param>
      </xsl:call-template>
    </segmentation>
    <segmentation name="SpeakerContribution_Event">
      <xsl:attribute name="tierref">
        <xsl:value-of select="@id"/>
      </xsl:attribute>
      <xsl:call-template name="segmentation-content">
        <xsl:with-param name="segment-type">event</xsl:with-param>
      </xsl:call-template>
    </segmentation>
    <xsl:apply-templates select="following-sibling::tier[not(@type='t')]
                                                        [preceding-sibling::tier[@type='t'][1]=current()]"/>
  </segmented-tier>
</xsl:template>

<xsl:template match="tier[not(@type='t')]">
  <annotation>
    <xsl:attribute name="name">
      <xsl:value-of select="@category"/>
    </xsl:attribute>
    <xsl:attribute name="tierref">
      <xsl:value-of select="@id"/>
    </xsl:attribute>
      <xsl:for-each select="event">
        <ta>
          <xsl:call-template name="event-content"/>
          <!-- <xsl:text>&#x20;</xsl:text> -->
        </ta>
      </xsl:for-each>
  </annotation>
</xsl:template>

<xsl:template match="tier[@type='t']"
              mode="conversion">
  <conversion-tier name="SpeakerContribution_Event">
    <xsl:attribute name="segmented-tier-id">
      <xsl:value-of select="@id"/>
    </xsl:attribute>
    <xsl:copy-of select="@category |
                         @display-name |
                         @type"/>
  </conversion-tier>
</xsl:template>

<xsl:template match="tier[not(@type='t')]"
              mode="conversion">
  <conversion-tier>
    <xsl:attribute name="name">
      <xsl:value-of select="@category"/>
    </xsl:attribute>
    <xsl:attribute name="segmented-tier-id">
      <xsl:value-of select="preceding-sibling::tier[@type='t'][1]/@id"/>
    </xsl:attribute>
    <xsl:copy-of select="@category |
                         @display-name |
                         @type"/>
  </conversion-tier>
</xsl:template>

<xsl:template match="tierformat-table"/>
</xsl:stylesheet>
